@@ -19,10 +19,22 @@ my %inits =
 );
 
 sub init {
-    my ($self, $init) = @_;
+    my ($self, $init) = @_; 
     my $stdout = '';
     my $stderr = '';
 
+    if( !$ENV{SDL_BSD_TEST} and $^O =~ /bsd|solaris/i) 
+    {
+	    warn "SDL Perl is experimental in BSD environments. \n Turn on SDL_BSD_TEST to test your system.";
+	    return ;
+    }
+
+    if( $init == SDL_INIT_TIMER and $^O =~ /bsd|solaris/i )
+    {
+	    warn ' Timer is REALLY experimental with BSD environments';
+	    return ;
+    } 
+
     if( $init == SDL_INIT_VIDEO)
     {
 	    if( $^O !~ /win/i && !$ENV{DISPLAY} )
@@ -42,11 +54,6 @@ sub init {
 	SDL::quit();
     }
 
-    if( $init == SDL_INIT_TIMER && $^O =~ /bsd|solaris/i) 
-    {
-	    warn "Timer is not supported in BSD environments";
-	    return ;
-    }
     capture { SDL::init($init) } \$stdout, \$stderr;
     if ( $stderr ne '' )
     {
